@@ -143,8 +143,10 @@ public class GenericResourceManager extends AbstractResourceManager {
 			resource.profile().type(subType.trim());
 	
 		ScopeProvider.instance.set(scope.toString());		
-		RegistryPublisher publisher = getRegistryPublisher();		
-		String id  = publisher.update(resource).id();
+		RegistryPublisher publisher = getRegistryPublisher();	
+		
+		//String id  = publisher.update(resource).id();
+		String id = publisher.vosUpdate(resource).id();
 		
 		if (id == null || id.length() == 0) {
 			throw new Exception("The GenericResource has not been updated");
